@@ -13,8 +13,12 @@ fn main() {
     let mut steps = collatz::get_steps(number);
     steps.insert(0, number); // Include actual number
     println!("Collatz steps {:?}", steps);
-    let data = steps.iter().enumerate().map(|(x,y)| (x as f32, *y as f32)).collect::<Vec<_>>();
+    let data = steps
+        .iter()
+        .enumerate()
+        .map(|(x, y)| (x as f32, *y as f32))
+        .collect::<Vec<_>>();
     Chart::new(180, 60, 0.0, steps.len() as f32)
         .lineplot(&Shape::Lines(&data))
         .display();
-}
\ No newline at end of file
+}
